==> media_plugin-0.0.1.tar.gz: lib/src/page/story_list_page.dart <==
// ignore_for_file: avoid_print

import 'package:file_picker/file_picker.dart';
import 'package:flutter/material.dart';
import 'package:media_plugin/src/page/story_page.dart';
import '../data/users.dart';
import '../model/story.dart';
import '../model/user.dart';
import '../widget/camer_picker.dart';
import '../widget/my_story.dart';

class StoryListPage extends StatelessWidget {
  const StoryListPage({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) => Scaffold(
    appBar: AppBar(
      title: const Text("Stories"),
    ),
    body: Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Padding(
          padding: const EdgeInsets.all(8.0),
          child: InkWell(
            onTap: () => _show(context),
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              children: const <Widget>[
                CircleAvatar(
                  radius: 24,
                  backgroundImage:  AssetImage('assets/user1.png'),
                ),
                SizedBox(width: 16),
                Text(
                  "Your Story",
                  style: TextStyle(
                    fontSize: 16,
                    fontWeight: FontWeight.bold,
                    color: Colors.black,
                  ),
                ),
              ],
            ),
          ),
        ),
        const Padding(
          padding: EdgeInsets.only(left: 10.0,top: 10,bottom: 10),
          child: Text("updated story",
            style: TextStyle(
              fontSize: 16,
              fontWeight: FontWeight.bold,
              color: Colors.blueGrey,
            ),
          ),
        ),
        ListView(
          shrinkWrap: true,
          children: users
              .map((user) => ListTile(
            title: Text(
              user.name,
              style: const TextStyle(
                fontSize: 18,
                fontWeight: FontWeight.bold,
              ),
            ),
            leading: CircleAvatar(
                backgroundImage: AssetImage(user.imgUrl)),
            onTap: () {
              Navigator.of(context).push(
                MaterialPageRoute(
                  builder: (context) => StoryPage(user: user),
                ),
              );
            },
          ))
              .toList(),
        ),
      ],
    ),
  );

  void openFile(BuildContext context, List<PlatformFile> files){
    List<Story> stories = [];
    for (final files in files){
      MediaType mediaType;
      if(files.extension?.contains('jpg') == true || files.extension?.contains('png') == true){
        mediaType = MediaType.image;
      }else {
        mediaType = MediaType.video;
      }
      stories.add(Story(
        mediaType: mediaType,
        url: files.path.toString(),
      ));
    }
    Navigator.of(context).push(
        MaterialPageRoute(builder: (context) => MyStoryScreen(stories: stories)
        )
    );
  }

  void _show(BuildContext context) {
    showDialog(
      context: context,
      builder: (_) {
        return SimpleDialog(
          title: const Text('Choose an Option'),
          children: [
            SimpleDialogOption(
              child: const Text('Camera'),
              onPressed: () async {
                Navigator.pop(context);
                await Navigator.of(context)
                    .push(MaterialPageRoute(builder: (context) => const CameraPage()));
              },
            ),
            SimpleDialogOption(
              child: const Text('Gallery'),
              onPressed: () async {
                Navigator.pop(context);
                final result = await FilePicker.platform.pickFiles(
                    allowMultiple: true,
                    type: FileType.custom,
                    allowedExtensions: ['jpg', 'png', 'mp4']
                );
                if(result == null) return;
                // ignore: use_build_context_synchronously
                openFile(context,result.files);
              },
            )
          ],
        );
      },
    );
  }

}

==> media_plugin-0.0.2.tar.gz: lib/src/page/story_list_page.dart <==
// ignore_for_file: avoid_print

import 'package:file_picker/file_picker.dart';
import 'package:flutter/material.dart';
import 'package:media_plugin/src/page/story_page.dart';
import '../data/users.dart';
import '../model/story.dart';
import '../model/user.dart';
import '../widget/camer_picker.dart';
import '../widget/my_story.dart';

class StoryListPage extends StatelessWidget {
  const StoryListPage({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) => Scaffold(
    appBar: AppBar(
      title: const Text("Stories"),
    ),
    body: Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Padding(
          padding: const EdgeInsets.all(8.0),
          child: InkWell(
            onTap: () => showDialogBox(context),
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              children: const <Widget>[
                CircleAvatar(
                  radius: 24,
                  backgroundImage:  AssetImage('assets/user1.png'),
                ),
                SizedBox(width: 16),
                Text(
                  "Your Story",
                  style: TextStyle(
                    fontSize: 16,
                    fontWeight: FontWeight.bold,
                    color: Colors.black,
                  ),
                ),
              ],
            ),
          ),
        ),
        const Padding(
          padding: EdgeInsets.only(left: 10.0,top: 10,bottom: 10),
          child: Text("updated story",
            style: TextStyle(
              fontSize: 16,
              fontWeight: FontWeight.bold,
              color: Colors.blueGrey,
            ),
          ),
        ),
        ListView(
          shrinkWrap: true,
          children: users
              .map((user) => ListTile(
            title: Text(
              user.name,
              style: const TextStyle(
                fontSize: 18,
                fontWeight: FontWeight.bold,
              ),
            ),
            leading: CircleAvatar(
                backgroundImage: AssetImage(user.imgUrl)),
            onTap: () {
              Navigator.of(context).push(
                MaterialPageRoute(
                  builder: (context) => StoryPage(user: user),
                ),
              );
            },
          ))
              .toList(),
        ),
      ],
    ),
  );

  void openFile(BuildContext context, List<PlatformFile> files){
    List<Story> stories = [];
    for (final files in files){
      MediaType mediaType;
      if(files.extension?.contains('jpg') == true || files.extension?.contains('png') == true){
        mediaType = MediaType.image;
      }else {
        mediaType = MediaType.video;
      }
      stories.add(Story(
        mediaType: mediaType,
        url: files.path.toString(),
      ));
    }
    Navigator.of(context).push(
        MaterialPageRoute(builder: (context) => MyStoryScreen(stories: stories)
        )
    );
  }

  void showDialogBox(BuildContext context) {
    showDialog(
      context: context,
      builder: (_) {
        return SimpleDialog(
          title: const Text('Choose an Option'),
          children: [
            SimpleDialogOption(
              child: const Text('Camera'),
              onPressed: () async {
                Navigator.pop(context);
                await Navigator.of(context)
                    .push(MaterialPageRoute(builder: (context) => const CameraPage()));
              },
            ),
            SimpleDialogOption(
              child: const Text('Gallery'),
              onPressed: () async {
                Navigator.pop(context);
                final result = await FilePicker.platform.pickFiles(
                    allowMultiple: true,
                    type: FileType.custom,
                    allowedExtensions: ['jpg', 'png', 'mp4']
                );
                if(result == null) return;
                // ignore: use_build_context_synchronously
                openFile(context,result.files);
              },
            )
          ],
        );
      },
    );
  }

}
